.. async_amqp documentation master file, created by
   sphinx-quickstart on Wed Mar 19 15:35:53 2014.

Welcome to async_amqp's documentation
====================================

AsyncAmqp is a library to connect to an amqp broker. It uses anyio under
the hood,  thus works with asyncio, trio or curio transparently.


Limitations
===========

For the moment, async_amqp is only tested against RabbitMQ.

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   api
   examples/index
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

